function L = estimate(e, model, x, t, varargin)
%
% ESTIMATE - evaluate resubstitution estimator for performance evaluation
%
%    L = ESTIMATE(RESUBSTITUTION,X,T) evaluates the resubstitution error (i.e.
%    the value of a performance criterion on the training set) for (highly
%    biased) performance evaluation or model selection.

%
% File        : @resubstitution/estimate.m
%
% Date        : Monday 27th August 2007
%
% Author      : Dr Gavin C. Cawley
%
% Description : Evaluate the resubstitution estimate of some performance
%               criterion for a generalised kernel machine.
%
% History     : 27/08/2007 - v1.00
%
% Copyright   : (c) Dr Gavin C. Cawley, August 2007.
%
%    This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program; if not, write to the Free Software
%    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
%

criterion = get(e, 'criterion'); 
model     = train(model, x, t, varargin{:});
[y, z]    = fwd(model, x);
L         = eval(criterion, model, t, y, z);

% bye bye...

